@@ -7,6 +7,7 @@ const char* wlife_t2str(wlife_t status) {
     switch(status) {
         case wlife_t::active: return "active";
         case wlife_t::shutdown: return "shutdown";
+        case wlife_t::finished: return "finished";
         case wlife_t::error: return "error";
         case wlife_t::proxy_cmd: return "proxy_cmd";
         case wlife_t::proxy_error: return "proxy_error";
@@ -22,7 +23,7 @@ int pending_interrupt() {
     return !(R_ToplevelExec(check_interrupt_fn, NULL));
 }
 
-zmq::message_t int2msg(int val) {
+zmq::message_t int2msg(const int val) {
     zmq::message_t msg(sizeof(int));
     memcpy(msg.data(), &val, sizeof(int));
     return msg;
@@ -36,7 +37,7 @@ zmq::message_t r2msg(SEXP data) {
     return msg;
 }
 
-SEXP msg2r(zmq::message_t &msg, bool unserialize) {
+SEXP msg2r(const zmq::message_t &&msg, const bool unserialize) {
     SEXP ans = Rf_allocVector(RAWSXP, msg.size());
     memcpy(RAW(ans), msg.data(), msg.size());
     if (unserialize)
@@ -45,8 +46,14 @@ SEXP msg2r(zmq::message_t &msg, bool unserialize) {
         return ans;
 }
 
-wlife_t msg2wlife_t(zmq::message_t &msg) {
+wlife_t msg2wlife_t(const zmq::message_t &msg) {
     wlife_t res;
     memcpy(&res, msg.data(), msg.size());
     return res;
 }
+
+std::string z85_encode_routing_id(const std::string rid) {
+    std::string dest(5, 0);
+    zmq_z85_encode(&dest[0], reinterpret_cast<const uint8_t*>(&rid[1]), 4);
+    return dest;
+}
